@@ -1,13 +1,12 @@
 package cPanel::TaskQueue::ChildProcessor;
-BEGIN {
-  $cPanel::TaskQueue::ChildProcessor::VERSION = '0.503_04';
-}
 
 use strict;
 #use warnings;
 use base 'cPanel::TaskQueue::Processor';
 use cPanel::TaskQueue::Scheduler;
 
+our $VERSION = 0.400;
+
 {
     sub get_child_timeout {
         my ($self) = @_;
@@ -35,10 +34,10 @@ use cPanel::TaskQueue::Scheduler;
     }
 
     sub process_task {
-        my ($self, $task, $logger) = @_;
+        my ($self, $task) = @_;
         my $pid = fork();
 
-        $logger->throw( q{Unable to start a child process to handle the '} . $task->command() . "' task\n" )
+        die "Unable to start a child process to handle the '" . $task->command() . "' task\n"
             unless defined $pid;
 
         # Parent returns
@@ -50,11 +49,11 @@ use cPanel::TaskQueue::Scheduler;
             local $SIG{'CHLD'} = 'DEFAULT';
             local $SIG{'ALRM'} = sub { die "timeout detected\n"; };
             $oldalarm = alarm $timeout;
-            $self->_do_child_task( $task, $logger );
+            $self->_do_child_task( $task );
             alarm $oldalarm;
-            1;
-        } or do {
-            my $ex = $@;
+        };
+        my $ex = $@;
+        if ( $ex ) {
             alarm $oldalarm;
             if ( $ex eq "timeout detected\n" ) {
                 eval {
@@ -64,18 +63,12 @@ use cPanel::TaskQueue::Scheduler;
                     # Handle retries
                     $self->retry_task( $task );
                 };
-                # Don't throw, we want to exit instead.
-                if( $@ ) {
-                    $logger->warn( $@ );
-                    exit 1;
-                }
+                die $@ if $@;
             }
             else {
-                # Don't throw, we want to exit instead.
-                $logger->warn( $ex );
-                exit 1;
+                die $ex;
             }
-        };
+        }
         exit 0;
     }
 
@@ -86,9 +79,9 @@ use cPanel::TaskQueue::Scheduler;
     }
 
     sub _do_child_task {
-        my ($self, $task, $logger) = @_;
+        my ($self, $task) = @_;
 
-        $logger->throw( "No child task defined.\n" );
+        die "No child task defined.\n";
     }
 }
 
